DEF_TITLE, DEF_INTERVAL = 'Process monitors', 5
DEF_HOST, DEF_PORT, DEF_ROOT_PATH = 'localhost', 5000, '/'
DEF_DB_TYPE, DEF_DB_HOST, DEF_DB_PORT, DEF_DB_NAME = 'mongo', 'localhost', 27017, 'tqdm'
DB_TYPES = ['mongo']
STATS_COLLECTION = '_stats_'
